==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/Backend.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Backend(
    virtualService: Option[zio.aws.appmesh.model.VirtualServiceBackend] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.appmesh.model.Backend = {
    import Backend.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.Backend
      .builder()
      .optionallyWith(virtualService.map(value => value.buildAwsValue()))(
        _.virtualService
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.Backend.ReadOnly =
    zio.aws.appmesh.model.Backend.wrap(buildAwsValue())
}
object Backend {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.appmesh.model.Backend] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.Backend = zio.aws.appmesh.model
      .Backend(virtualService.map(value => value.asEditable))
    def virtualService
        : Option[zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly]
    def getVirtualService: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly
    ] = AwsError.unwrapOptionField("virtualService", virtualService)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.Backend
  ) extends zio.aws.appmesh.model.Backend.ReadOnly {
    override val virtualService
        : Option[zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly] = scala
      .Option(impl.virtualService())
      .map(value => zio.aws.appmesh.model.VirtualServiceBackend.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.Backend
  ): zio.aws.appmesh.model.Backend.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.206.1-sources.jar: zio/aws/appmesh/model/Backend.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Backend(
    virtualService: Optional[zio.aws.appmesh.model.VirtualServiceBackend] =
      Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.appmesh.model.Backend = {
    import Backend.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.Backend
      .builder()
      .optionallyWith(virtualService.map(value => value.buildAwsValue()))(
        _.virtualService
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.Backend.ReadOnly =
    zio.aws.appmesh.model.Backend.wrap(buildAwsValue())
}
object Backend {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.appmesh.model.Backend] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.Backend = zio.aws.appmesh.model
      .Backend(virtualService.map(value => value.asEditable))
    def virtualService
        : Optional[zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly]
    def getVirtualService: ZIO[
      Any,
      AwsError,
      zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly
    ] = AwsError.unwrapOptionField("virtualService", virtualService)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.Backend
  ) extends zio.aws.appmesh.model.Backend.ReadOnly {
    override val virtualService
        : Optional[zio.aws.appmesh.model.VirtualServiceBackend.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.virtualService())
        .map(value => zio.aws.appmesh.model.VirtualServiceBackend.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.Backend
  ): zio.aws.appmesh.model.Backend.ReadOnly = new Wrapper(impl)
}
